package com.ym.mec.biz.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ym.mec.auth.api.client.SysUserFeignService;
import com.ym.mec.auth.api.entity.SysUser;
import com.ym.mec.biz.dal.dao.TenantConfigDao;
import com.ym.mec.biz.dal.dto.TenantConfigDto;
import com.ym.mec.biz.dal.entity.TenantConfig;
import com.ym.mec.biz.service.TenantConfigService;
import com.ym.mec.common.exception.BizException;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.Objects;
import java.util.Optional;
import java.util.function.Consumer;

/**
 * @author hgw
 * Created by 2021-12-02
 */
@Service
public class TenantConfigServiceImpl extends ServiceImpl<TenantConfigDao, TenantConfig> implements TenantConfigService {

    @Autowired
    private SysUserFeignService sysUserFeignService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addConfig(TenantConfigDto dto) {
        setUserId(dto.getUpdatedBy(), dto::setUpdatedBy);
        TenantConfig info = new TenantConfig();
        info.setUpdatedTime(new Date());
        BeanUtils.copyProperties(dto, info);
        this.save(info);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateConfig(TenantConfigDto dto) {
        setUserId(dto.getUpdatedBy(), dto::setUpdatedBy);
        TenantConfig info = new TenantConfig();
        BeanUtils.copyProperties(dto, info);
        this.updateById(info);
    }

    private void setUserId(Integer id, Consumer<Integer> setOption) {
        if (Objects.isNull(id)) {
            Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                    .map(SysUser::getId)
                    .orElseThrow(() -> new BizException("用户信息获取失败"));
            setOption.accept(userId);
        }
    }
}
