package com.ym.mec.web.controller;

import com.ym.mec.biz.dal.dto.TenantInfoDto;
import com.ym.mec.biz.service.TenantInfoService;
import com.ym.mec.common.controller.BaseController;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Map;

/**
 * @author hgw
 * Created by 2021-12-07
 */
@RequestMapping("/tenantInfo")
@Api(tags = "机构管理")
@RestController
public class TenantInfoController extends BaseController {

    @Autowired
    private TenantInfoService tenantInfoService;

    @ApiOperation("添加机构信息")
    @PostMapping(value = "/add")
//    @PreAuthorize("@pcs.hasPermissions('tenantInfo/add')")
    public Object addTenantInfo(@Valid @RequestBody TenantInfoDto dto) {
        tenantInfoService.addTenantInfo(dto);
        return succeed();
    }

    @ApiOperation("修改机构信息")
    @PostMapping(value = "/update")
    @PreAuthorize("@pcs.hasPermissions('tenantInfo/update')")
    public Object updateTenantInfo(@Valid @RequestBody TenantInfoDto dto) {
        tenantInfoService.updateTenantInfo(dto);
        return succeed();
    }

    @ApiOperation("修改机构启用停用状态")
    @GetMapping(value = "/opsState/{id}")
    @PreAuthorize("@pcs.hasPermissions('tenantInfo/opsState')")
    public Object opsState(@ApiParam(value = "机构ID", required = true) @PathVariable("id") Integer id, Integer state) {
        tenantInfoService.opsTenantState(id, state);
        return succeed();
    }

    @ApiOperation("查询单个机构详情")
    @GetMapping(value = "/info/{id}")
    @PreAuthorize("@pcs.hasPermissions('tenantInfo/info')")
    public Object queryTenantInfo(@ApiParam(value = "机构ID", required = true) @PathVariable("id") Integer id) {
        return succeed(tenantInfoService.queryTenantInfo(id));
    }


    @ApiImplicitParams({
            @ApiImplicitParam(name = "search", dataType = "String", value = "关键字"),
            @ApiImplicitParam(name = "createdName", dataType = "String", value = "创建人"),
            @ApiImplicitParam(name = "payState", dataType = "Integer", value = "支付状态 缴费状态 0未缴费  1已缴费"),
            @ApiImplicitParam(name = "state", dataType = "Integer", value = "机构状态 1启动 2停用"),
            @ApiImplicitParam(name = "startDate", dataType = "String", value = "开始时间"),
            @ApiImplicitParam(name = "endDate", dataType = "String", value = "结束时间"),
            @ApiImplicitParam(name = "page", dataType = "Integer", value = "页数"),
            @ApiImplicitParam(name = "rows", dataType = "Integer", value = "每页数量"),
    })
    @ApiOperation("分页查询")
    @PostMapping(value = "/queryPage")
    @PreAuthorize("@pcs.hasPermissions('tenantInfo/queryPage')")
    public Object queryPage(@RequestBody Map<String, Object> param) {
        return succeed(tenantInfoService.queryPage(param));
    }

}
